@@ -80,8 +80,8 @@ long one_frame = 60;
 int pic_mode = 0;		//0 - none; 1 - pic fade in; 2 - pic fade out;
 int pic_fade = 0;
 
-#ifdef HAVE_IMAGEMAGICK
 #include <magick/api.h>
+#include <wand/magick-wand.h>
 #include <dirent.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -94,13 +94,13 @@ unsigned char *next_pic = NULL;
 
 // Directory scanning + image loading code in a separate function callable either from loadNextImage or another thread if pthreads is available.
 void loadNextImageFromDisk() {
+	MagickWand *magick_wand = NewMagickWand();
 	ExceptionInfo exception;
-	Image *image = NULL, *scaled_image;
-	ImageInfo *image_info;
 	int dirLoop = 0;
 
 	GetExceptionInfo (&exception);
 
+	int imageLoaded = 0;
 	do {
 		struct dirent *file;
 
@@ -124,18 +124,15 @@ void loadNextImageFromDisk() {
 
 				if (!stat(full_path_and_name, (struct stat *)&fileStat)) {
 					if (S_ISREG(fileStat.st_mode)) {
-						FILE *imagefh = fopen(full_path_and_name, "r");
+						if (MagickReadImage(magick_wand, full_path_and_name) == MagickFalse) {
+							char *description;
+							ExceptionType severity;
 
-						if (imagefh) {
-							image_info = CloneImageInfo ((ImageInfo *) NULL);
-							image_info->file = imagefh;
-							image = ReadImage (image_info, &exception);
-
-							if (exception.severity != UndefinedException) {
-								fprintf (stderr, "Error loading %s: %s\n", full_path_and_name, exception.reason);
-							}
+							description = MagickGetException (magick_wand, &severity);
+							fprintf (stderr, "Error loading %s: %s\n", full_path_and_name, description);
+							description = (char *)MagickRelinquishMemory (description);
 						} else {
-							fprintf (stderr, "Unable to open %s: %s\n", full_path_and_name, exception.reason);
+							imageLoaded = 1;
 						}
 					}
 				}
@@ -145,22 +142,22 @@ void loadNextImageFromDisk() {
 				fprintf (stderr, "Out of memory\n");
 			}
 		} else {
+			closedir(imageDir);
 			imageDir = NULL;
 		}
-	} while (!image);
+	} while (!imageLoaded);
 
-	scaled_image = ScaleImage (image, text_x, text_y, &exception);
-	NormalizeImage(scaled_image);
-	ContrastImage(scaled_image, 0);
-	NegateImage(scaled_image, 0);
+	MagickScaleImage (magick_wand, text_x, text_y);
+	MagickNormalizeImage (magick_wand);
+	MagickContrastImage (magick_wand, MagickTrue);
+	MagickNegateImage (magick_wand, MagickFalse);
 
 	if (!next_pic)
 		next_pic = (unsigned char *)malloc (text_x * text_y);
 
-	ExportImagePixels (scaled_image, 0, 0, text_x, text_y, "I", CharPixel, next_pic, &exception);
+	ExportImagePixels (GetImageFromMagickWand(magick_wand), 0, 0, text_x, text_y, "I", CharPixel, next_pic, &exception);
 
-	DestroyImage (image);
-	DestroyImage (scaled_image);
+	magick_wand = DestroyMagickWand (magick_wand);
 }
 
 #ifdef HAVE_PTHREADS
@@ -181,12 +178,8 @@ void *imageLoadingThreadMain() {
 }
 #endif
 
-#endif
-
-
 void loadNextImage ()
 {
-#ifdef HAVE_IMAGEMAGICK
 	if (dirName) {
 #ifdef HAVE_PTHREADS
 		if (!imageLoadingThread) {
@@ -238,7 +231,7 @@ void loadNextImage ()
 			strcpy(image_info->size, "90x70");
 			image = AllocateImage(image_info);
 
-			ImportImagePixels(image, 0, 0, 90, 70, "I", CharPixel, (unsigned char *)((int)pics + ((random () & 15) * (90 * 70))));
+			ImportImagePixels(image, 0, 0, 90, 70, "I", CharPixel, (unsigned char *)(pics + ((random () & 15) * (90 * 70))));
 
 			scaled_image = ScaleImage (image, text_x, text_y, &exception);
 
@@ -247,15 +240,12 @@ void loadNextImage ()
 			DestroyImage (image);
 			DestroyImage (scaled_image);
 		} else {
-#endif
 			if (!pics)
 				LOAD_TEXTURE (pics, cpics, cpics_compressedsize, cpics_size)
 
-			pic = (unsigned char *)((int)pics + ((random () & 15) * (text_x * text_y)));
-#ifdef HAVE_IMAGEMAGICK
+			pic = (unsigned char *)(pics + ((random () & 15) * (text_x * text_y)));
 		}
 	}
-#endif
 }
 
 void draw_char (long num, float light, float x, float y, float z)
@@ -453,7 +443,7 @@ void scroll (double dCurrentTime)
 		//for (a = (text_x * text_y) + text_x - 1; a > text_x; a--) {
 		//      text_light[a] = text_light[a - text_x]; //scroll light table down
 		//}
-		memmove ((void *)((int)&text_light + text_x), (void *)&text_light, (text_x * text_y) - 1);
+		memmove ((void *)(&text_light[0] + text_x), (void *)&text_light, (text_x * text_y) - 1);
 
 		//for (a = 0; a < text_x; a++)
 		//      text_light[a] = 253;    //clear top line (in light table)
@@ -569,9 +559,7 @@ void hack_init (xstuff_t * XStuff)	// Called right after the window is created,
 	load_texture ();
 	make_text ();
 
-#ifdef HAVE_IMAGEMAGICK
-	InitializeMagick (NULL);
-#endif
+	MagickWandGenesis ();
 
 	ourBuildTextures ();
 
@@ -600,7 +588,6 @@ void hack_init (xstuff_t * XStuff)	// Called right after the window is created,
 
 void hack_cleanup (xstuff_t * XStuff)
 {
-#ifdef HAVE_IMAGEMAGICK
 #ifdef HAVE_PTHREADS
 	if (imageLoadingThread) {
 		// Try acquiring the lock first to make sure the thread is asleep and signallable. Otherwise the signal will miss the other thread and the pthread_join will hang.
@@ -614,7 +601,6 @@ void hack_cleanup (xstuff_t * XStuff)
 		pthread_join(*imageLoadingThread, NULL);
 	}
 #endif
-#endif
 }
 
 void hack_draw (xstuff_t * XStuff, double currentTime, float frameTime)
@@ -666,14 +652,6 @@ void hack_draw (xstuff_t * XStuff, double currentTime, float frameTime)
 	glMatrixMode (GL_PROJECTION);
 }
 
-#ifdef HAVE_IMAGEMAGICK
-#define HAVE_IMAGEMAGICK_OPTIONS_SHORT "i:"
-#define HAVE_IMAGEMAGICK_OPTIONS_LONG "\t--images/-i <arg>\n"
-#else
-#define HAVE_IMAGEMAGICK_OPTIONS_SHORT 
-#define HAVE_IMAGEMAGICK_OPTIONS_LONG 
-#endif
-
 void hack_handle_opts (int argc, char **argv)
 {
 	while (1) {
@@ -683,9 +661,7 @@ void hack_handle_opts (int argc, char **argv)
 		static struct option long_options[] = {
 			{"help", 0, 0, 'h'},
 			DRIVER_OPTIONS_LONG 
-#ifdef HAVE_IMAGEMAGICK
 			{"images", 1, 0, 'i'},
-#endif
 			{"scene_interval", 1, 0, 's'},
 			{"matrix_interval", 1, 0, 'm'},
 			{"matrix_width", 1, 0, 'X'},
@@ -694,9 +670,9 @@ void hack_handle_opts (int argc, char **argv)
 			{0, 0, 0, 0}
 		};
 
-		c = getopt_long (argc, argv, DRIVER_OPTIONS_SHORT "hs:m:X:Y:c:" HAVE_IMAGEMAGICK_OPTIONS_SHORT, long_options, NULL);
+		c = getopt_long (argc, argv, DRIVER_OPTIONS_SHORT "hs:m:X:Y:c:i:", long_options, NULL);
 #else
-		c = getopt (argc, argv, DRIVER_OPTIONS_SHORT "hs:m:X:Y:c:" HAVE_IMAGEMAGICK_OPTIONS_SHORT);
+		c = getopt (argc, argv, DRIVER_OPTIONS_SHORT "hs:m:X:Y:c:i:");
 #endif
 		if (c == -1)
 			break;
@@ -706,12 +682,11 @@ void hack_handle_opts (int argc, char **argv)
 #ifndef HAVE_GETOPT_H
 							      " Not built with GNU getopt.h, long options *NOT* enabled."
 #endif
-							      "\n" DRIVER_OPTIONS_HELP HAVE_IMAGEMAGICK_OPTIONS_LONG "\t--scene_interval/-s <arg>\n" "\t--matrix_interval/-m <arg>\n"
+							      "\n" DRIVER_OPTIONS_HELP "\t--images/-i <arg>\n\t--scene_interval/-s <arg>\n" "\t--matrix_interval/-m <arg>\n"
 								  "\t--matrix_width/-X <arg>\n" "\t--matrix_height/-Y <arg>\n" "\t--contrast/-c <arg>\n", argv[0]);
 
 			exit (1);
 
-#ifdef HAVE_IMAGEMAGICK
 		case 'i':
 			{
 				struct stat fileStat;
@@ -734,7 +709,6 @@ void hack_handle_opts (int argc, char **argv)
 			}
 
 			break;
-#endif
 		case 's':
 			cycleScene = strtol_minmaxdef (optarg, 10, 0, 120, 1, 5, "--scene_interval: ");
 			break;
