@@ -20,23 +20,21 @@
 
 #include <math.h>
 #include <stdio.h>
-#include <time.h>
 #include <GL/gl.h>
 #include <GL/glu.h>
 #include <GL/glx.h>
-#include <sys/time.h>
 
 #include "driver.h"
-#include "impCubeVolume.h"
-#include "impCrawlPoint.h"
-#include "impSphere.h"
+#include "Implicit/impCubeVolume.h"
+#include "Implicit/impCrawlPoint.h"
+#include "Implicit/impSphere.h"
 #include "loadTexture.h"
 #include "rgbhsl.h"
 #include "rsDefines.h"
 #include "rsRand.h"
-#include "rsMatrix.h"
-#include "rsQuat.h"
-#include "rsVec.h"
+#include "rsMath/rsMatrix.h"
+#include "rsMath/rsQuat.h"
+#include "rsMath/rsVec.h"
 
 char *hack_name = (char *)"helios";
 
@@ -74,7 +72,6 @@ int dCameraspeed;
 int dSurface;
 int dWireframe;
 int dBlur;
-int dPriority;
 
 impCubeVolume *volume;
 impSurface *surface;
@@ -108,7 +105,7 @@ class emitter:public particle {
 
 emitter::emitter ()
 {
-	pos = rsVec (myRandf (1000.0f) - 500.0f, myRandf (1000.0f) - 500.0f, myRandf (1000.0f) - 500.0f);
+	pos = rsVec (rsRandf (1000.0f) - 500.0f, rsRandf (1000.0f) - 500.0f, rsRandf (1000.0f) - 500.0f);
 }
 
 class attracter:public particle {
@@ -132,7 +129,7 @@ class attracter:public particle {
 
 attracter::attracter ()
 {
-	pos = rsVec (myRandf (1000.0f) - 500.0f, myRandf (1000.0f) - 500.0f, myRandf (1000.0f) - 500.0f);
+	pos = rsVec (rsRandf (1000.0f) - 500.0f, rsRandf (1000.0f) - 500.0f, rsRandf (1000.0f) - 500.0f);
 }
 
 class ion:public particle {
@@ -153,7 +150,7 @@ ion::ion ()
 
 	pos = rsVec (0.0f, 0.0f, 0.0f);
 	rgb = rsVec (0.0f, 0.0f, 0.0f);
-	temp = myRandf (2.0f) + 0.4f;
+	temp = rsRandf (2.0f) + 0.4f;
 	size = float (dSize) * temp;
 	speed = float (dSpeed) * 12.0f / temp;
 }
@@ -161,12 +158,12 @@ ion::ion ()
 void
   ion::start ()
 {
-	int i = myRandi (dEmitters);
+	int i = rsRandi (dEmitters);
 	float offset = elapsedTime * speed;
 
 	pos = elist[i].pos;
 
-	switch (myRandi (14)) {
+	switch (rsRandi (14)) {
 	case 0:
 		pos[0] += offset;
 		break;
@@ -293,9 +290,9 @@ void setTargets (int whichTarget)
 	switch (whichTarget) {
 	case 0:		// random
 		for (i = 0; i < dEmitters; i++)
-			elist[i].settargetpos (rsVec (rsVec (myRandf (1000.0f) - 500.0f, myRandf (1000.0f) - 500.0f, myRandf (1000.0f) - 500.0f)));
+			elist[i].settargetpos (rsVec (rsVec (rsRandf (1000.0f) - 500.0f, rsRandf (1000.0f) - 500.0f, rsRandf (1000.0f) - 500.0f)));
 		for (i = 0; i < dAttracters; i++)
-			alist[i].settargetpos (rsVec (rsVec (myRandf (1000.0f) - 500.0f, myRandf (1000.0f) - 500.0f, myRandf (1000.0f) - 500.0f)));
+			alist[i].settargetpos (rsVec (rsVec (rsRandf (1000.0f) - 500.0f, rsRandf (1000.0f) - 500.0f, rsRandf (1000.0f) - 500.0f)));
 		break;
 	case 1:
 		{		// line (all emitters on one side, all attracters on the other)
@@ -377,21 +374,21 @@ void setTargets (int whichTarget)
 		}
 	case 5:		// random distribution across a plane
 		for (i = 0; i < dEmitters; i++)
-			elist[i].settargetpos (rsVec (rsVec (myRandf (1000.0f) - 500.0f, 0.0f, myRandf (1000.0f) - 500.0f)));
+			elist[i].settargetpos (rsVec (rsVec (rsRandf (1000.0f) - 500.0f, 0.0f, rsRandf (1000.0f) - 500.0f)));
 		for (i = 0; i < dAttracters; i++)
-			alist[i].settargetpos (rsVec (rsVec (myRandf (1000.0f) - 500.0f, 0.0f, myRandf (1000.0f) - 500.0f)));
+			alist[i].settargetpos (rsVec (rsVec (rsRandf (1000.0f) - 500.0f, 0.0f, rsRandf (1000.0f) - 500.0f)));
 		break;
 	case 6:
 		{		// random distribution across 2 planes
 			float height = -525.0f + float (dEmitters * 25);
 
 			for (i = 0; i < dEmitters; i++)
-				elist[i].settargetpos (rsVec (rsVec (myRandf (1000.0f) - 500.0f, height, myRandf (1000.0f) - 500.0f)));
+				elist[i].settargetpos (rsVec (rsVec (rsRandf (1000.0f) - 500.0f, height, rsRandf (1000.0f) - 500.0f)));
 
 			height = 525.0f - float (dAttracters * 25);
 
 			for (i = 0; i < dAttracters; i++)
-				alist[i].settargetpos (rsVec (rsVec (myRandf (1000.0f) - 500.0f, height, myRandf (1000.0f) - 500.0f)));
+				alist[i].settargetpos (rsVec (rsVec (rsRandf (1000.0f) - 500.0f, height, rsRandf (1000.0f) - 500.0f)));
 
 			break;
 		}
@@ -484,7 +481,7 @@ float surfaceFunction (float *position)
 	return (value);
 }
 
-void hack_draw (xstuff_t * XStuff)
+void hack_draw (xstuff_t * XStuff, double currentTime, float frameTime)
 {
 	int i;
 	static int ionsReleased = 0;
@@ -495,21 +492,8 @@ void hack_draw (xstuff_t * XStuff)
 #endif
 
 	Window window = XStuff->window;
-	static int thisTime, lastTime;
-	struct timeval now;
 
-	/*
-	 * update time 
-	 */
-	gettimeofday (&now, NULL);
-	thisTime = (now.tv_sec & 65535) * 1000 + now.tv_usec / 1000;
-
-	if (lastTime == -1)
-		lastTime = thisTime;
-
-	if (thisTime >= lastTime)
-		elapsedTime = (thisTime - lastTime) * 0.001f;
-	lastTime = thisTime;
+	elapsedTime = frameTime;
 
 #ifdef BENCHMARK
 	if (a++ == 1000)
@@ -532,10 +516,11 @@ void hack_draw (xstuff_t * XStuff)
 
 	if (preCameraInterp >= PI) {
 		oldCameraDistance = targetCameraDistance;
-		targetCameraDistance = -myRandf (1300.0f) - 200.0f;
+		targetCameraDistance = -rsRandf (1300.0f) - 200.0f;
 		preCameraInterp = 0.0f;
 	}
 
+	glMatrixMode (GL_MODELVIEW);
 	glLoadIdentity ();
 	glTranslatef (0.0, 0.0, cameraDistance);
 
@@ -553,10 +538,10 @@ void hack_draw (xstuff_t * XStuff)
 		radialVel += radialVelDiff;
 	} else {
 		radialVel = targetRadialVel;
-		if (myRandi (2)) {
-			targetRadialVel = rsVec (myRandf (1.0f), myRandf (1.0f), myRandf (1.0f));
+		if (rsRandi (2)) {
+			targetRadialVel = rsVec (rsRandf (1.0f), rsRandf (1.0f), rsRandf (1.0f));
 			targetRadialVel.normalize ();
-			targetRadialVel *= float (dCameraspeed) * myRandf (0.002f);
+			targetRadialVel *= float (dCameraspeed) * rsRandf (0.002f);
 		} else
 			targetRadialVel = rsVec (0.0f, 0.0f, 0.0f);
 	}
@@ -576,18 +561,18 @@ void hack_draw (xstuff_t * XStuff)
 	rotMat.get (billboardMat);
 
 	// Calculate new color
-	static rsVec oldHsl, newHsl = rsVec (myRandf (1.0f), 1.0f, 1.0f), targetHsl;
+	static rsVec oldHsl, newHsl = rsVec (rsRandf (1.0f), 1.0f, 1.0f), targetHsl;
 	static float colorInterp = 1.0f, colorChange;
 
 	colorInterp += elapsedTime * colorChange;
 	if (colorInterp >= 1.0f) {
-		if (!myRandi (3) && dIons >= 100)	// change color suddenly
-			newHsl = rsVec (myRandf (1.0f), 1.0f - (myRandf (1.0f) * myRandf (1.0f)), 1.0f);
+		if (!rsRandi (3) && dIons >= 100)	// change color suddenly
+			newHsl = rsVec (rsRandf (1.0f), 1.0f - (rsRandf (1.0f) * rsRandf (1.0f)), 1.0f);
 		oldHsl = newHsl;
-		targetHsl = rsVec (myRandf (1.0f), 1.0f - (myRandf (1.0f) * myRandf (1.0f)), 1.0f);
+		targetHsl = rsVec (rsRandf (1.0f), 1.0f - (rsRandf (1.0f) * rsRandf (1.0f)), 1.0f);
 		colorInterp = 0.0f;
 		// amount by which to change colorInterp each second
-		colorChange = myRandf (0.005f * float (dSpeed)) + (0.002f * float (dSpeed));
+		colorChange = rsRandf (0.005f * float (dSpeed)) + (0.002f * float (dSpeed));
 	} else {
 		float diff = targetHsl[0] - oldHsl[0];
 
@@ -630,7 +615,7 @@ void hack_draw (xstuff_t * XStuff)
 		static int newTarget = 0, lastTarget;
 
 		lastTarget = newTarget;
-		newTarget = myRandi (10);
+		newTarget = rsRandi (10);
 		if (newTarget == lastTarget)
 			newTarget++;
 		setTargets (newTarget);
@@ -638,7 +623,7 @@ void hack_draw (xstuff_t * XStuff)
 		interp = 0.0f;
 		wait = 10.0f;	// pause after forming each new pattern
 		interpconst = 0.001f;
-		if (!myRandi (4))	// interpolate really fast sometimes
+		if (!rsRandi (4))	// interpolate really fast sometimes
 			interpconst = 0.1f;
 	}
 	// Update particles
@@ -659,39 +644,45 @@ void hack_draw (xstuff_t * XStuff)
 			spheres[i].setPosition (elist[i].pos[0], elist[i].pos[1], elist[i].pos[2]);
 		for (i = 0; i < dAttracters; i++)
 			spheres[dEmitters + i].setPosition (alist[i].pos[0], alist[i].pos[1], alist[i].pos[2]);
-		std::list < impCrawlPoint > crawlpointlist;
-		float center[3];
 
-		for (i = 0; i < dEmitters + dAttracters; i++) {
-			spheres[i].center (center);
-			crawlpointlist.push_back (impCrawlPoint (center));
-		}
+		impCrawlPointVector cpv;
+		for(i=0; i<dEmitters+dAttracters; i++)
+			spheres[i].addCrawlPoint(cpv);
+
 		surface->reset ();
-		static float valuetrig = 0.0f;
 
+		static float valuetrig = 0.0f;
 		valuetrig += elapsedTime;
-		volume->surfacevalue = 0.45f + 0.05f * cos (valuetrig);
-		volume->make_surface (crawlpointlist);
+
+		volume->setSurfaceValue(0.45f + 0.05f * cosf(valuetrig));
+		volume->makeSurface(cpv);
 	}
 	// Draw
 	// clear the screen
 	if (dBlur) {		// partially
-		glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-		glColor4f (0.0f, 0.0f, 0.0f, 0.5f - (float (sqrt (sqrt (double (dBlur)))) * 0.15495f));
-
+		glMatrixMode (GL_PROJECTION);
 		glPushMatrix ();
-		glLoadIdentity ();
-		glBegin (GL_TRIANGLE_STRIP);
-		glVertex3f (-5.0f, -4.0f, -3.0f);
-		glVertex3f (5.0f, -4.0f, -3.0f);
-		glVertex3f (-5.0f, 4.0f, -3.0f);
-		glVertex3f (5.0f, 4.0f, -3.0f);
-		glEnd ();
-		glPopMatrix ();
+			glLoadIdentity();
+			glOrtho(0.0, 1.0, 0.0, 1.0, 1.0, -1.0);
+			glMatrixMode(GL_MODELVIEW);
+			glPushMatrix();
+				glLoadIdentity();
+				glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+				glColor4f(0.0f, 0.0f, 0.0f, 0.5f - (float(sqrtf(sqrtf(float(dBlur)))) * 0.15495f));
+				glBegin(GL_TRIANGLE_STRIP);
+					glVertex3f(0.0f, 0.0f, 0.0f);
+					glVertex3f(1.0f, 0.0f, 0.0f);
+					glVertex3f(0.0f, 1.0f, 0.0f);
+					glVertex3f(1.0f, 1.0f, 0.0f);
+			glEnd();
+		glPopMatrix();
+		glMatrixMode(GL_PROJECTION);
+		glPopMatrix();
 	} else			// completely
 		glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 
 	// Draw ions
+	glMatrixMode(GL_MODELVIEW);
 	glBlendFunc (GL_ONE, GL_ONE);
 	glBindTexture (GL_TEXTURE_2D, 1);
 	for (i = 0; i < ionsReleased; i++)
@@ -796,12 +787,6 @@ void hack_reshape (xstuff_t * XStuff)
 	glMatrixMode (GL_PROJECTION);
 	glLoadIdentity ();
 	gluPerspective (60.0, float (XStuff->windowWidth) / float (XStuff->windowHeight), 0.1, 10000.0f);
-
-	glMatrixMode (GL_MODELVIEW);
-
-	glDisable (GL_DEPTH_TEST);
-	glEnable (GL_BLEND);
-	glLightModeli (GL_LIGHT_MODEL_LOCAL_VIEWER, GL_TRUE);
 }
 
 void hack_init (xstuff_t * XStuff)
@@ -813,8 +798,11 @@ void hack_init (xstuff_t * XStuff)
 	// Window initialization
 	hack_reshape (XStuff);
 
+	glDisable (GL_DEPTH_TEST);
+	glEnable (GL_BLEND);
+	glLightModeli (GL_LIGHT_MODEL_LOCAL_VIEWER, GL_TRUE);
+
 	// Clear the buffers and test for type of buffer swapping
-	// glClearColor(0.0f, 0.0f, 0.0f, 1.0f);
 	glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 	glXSwapBuffers (XStuff->display, XStuff->window);	// wglSwapLayerBuffers(hdc, WGL_SWAP_MAIN_PLANE);
 	glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
@@ -893,16 +881,15 @@ void hack_init (xstuff_t * XStuff)
 		volume = new impCubeVolume;
 		volume->init (50, 50, 50, 35.0f);
 		volume->function = surfaceFunction;
-		surface = new impSurface;
-		surface->init (6000);
-		volume->surface = surface;
-		spheres = new impSphere[dEmitters + dAttracters];
-		float sphereScaleFactor = 1.0f / float (sqrt (double (2 * dEmitters + dAttracters)));
+		surface = volume->getSurface();
 
+		spheres = new impSphere[dEmitters + dAttracters];
+
+		float sphereScaleFactor = 1.0f / sqrtf (double (2 * dEmitters + dAttracters));
 		for (i = 0; i < dEmitters; i++)
-			spheres[i].setScale (400.0f * sphereScaleFactor);
+			spheres[i].setThickness (400.0f * sphereScaleFactor);
 		for (i = 0; i < dAttracters; i++)
-			spheres[i + dEmitters].setScale (200.0f * sphereScaleFactor);
+			spheres[i + dEmitters].setThickness (200.0f * sphereScaleFactor);
 	}
 }
 
