@@ -46,4 +46,10 @@ typedef struct xstuff {
 void handle_global_opts (int c);
 int strtol_minmaxdef(char *optarg, int base, int min, int max, int type, int def, char *errmsg);
 
+void hack_handle_opts (int argc, char **argv);
+void hack_init (xstuff_t *);
+void hack_reshape (xstuff_t *);
+void hack_draw (xstuff_t *, double, float);
+void hack_cleanup (xstuff_t *);
+
 #endif
